/* Atomixed -- the level-/themeeditor for atomix.
 * Copyright (C) 1999-2000 Jens Finke
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
#include "level_properties.h"
#include "main.h"
#include "support.h"

static Level *current_level = NULL;

static gboolean theme_changed = FALSE;
static gboolean level_name_changed = FALSE;

void level_properties_set_level(Level *level)
{
	current_level = level;
	level_properties_update_view();
}

void level_properties_delete_level(void)
{
	current_level = NULL;
}

void level_properties_update_view(void)
{
	GtkWidget *en_level_name;
	GtkWidget *en_theme_name;
	GtkWidget *en_file_name;
	GtkWidget *sb_time_minutes;
	GtkWidget *sb_time_seconds;
	guint minutes;
	guint seconds;

	g_return_if_fail(current_level!=NULL);
	
	/* set level name */
	en_level_name = lookup_widget(get_app(), "level_name");
	gtk_entry_set_text(GTK_ENTRY(en_level_name), current_level->name);

	/* set theme name */
	en_theme_name = lookup_widget(get_app(), "theme_name_entry");
	gtk_entry_set_text(GTK_ENTRY(en_theme_name), 
			   current_level->theme_name);

	/* set file name */
	en_file_name = lookup_widget(get_app(), "file_name");
	gtk_entry_set_text(GTK_ENTRY(en_file_name), current_level->file_name);

	/* set time */
	minutes = current_level->time / 60;
	seconds = current_level->time % 60;
	sb_time_minutes = lookup_widget(get_app(), "time_minutes");
	sb_time_seconds = lookup_widget(get_app(), "time_seconds");
	gtk_spin_button_set_value(GTK_SPIN_BUTTON(sb_time_minutes),
				  minutes);
	gtk_spin_button_set_value(GTK_SPIN_BUTTON(sb_time_seconds),
				  seconds);
}

void level_properties_update_level(void)
{
	if(current_level != NULL)
	{
		GtkWidget *en_level_name;
		GtkWidget *en_theme_name;
		GtkWidget *en_file_name;
		GtkWidget *sb_time_minutes;
		GtkWidget *sb_time_seconds;
		guint minutes;
		guint seconds;

		/* update name */
		en_level_name = lookup_widget(get_app(), "level_name");
		if(current_level->name) g_free(current_level->name);
		current_level->name = gtk_editable_get_chars(GTK_EDITABLE(en_level_name),0,-1);
		
		/* update theme name */
		en_theme_name = lookup_widget(get_app(), "theme_name_entry");
		if(current_level->theme_name) g_free(current_level->theme_name);
		current_level->theme_name = gtk_editable_get_chars(GTK_EDITABLE(en_theme_name),
								   0,-1);
		
		/* update file name */
		en_file_name = lookup_widget(get_app(), "file_name");
		if(current_level->file_name) g_free(current_level->file_name);
		current_level->file_name = gtk_editable_get_chars(GTK_EDITABLE(en_file_name),
								  0,-1);
		
		/* update time */
		sb_time_minutes = lookup_widget(get_app(), "time_minutes");
		sb_time_seconds = lookup_widget(get_app(), "time_seconds");
		minutes = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(sb_time_minutes));
		seconds = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(sb_time_seconds));
		current_level->time = minutes*60 + seconds;
	}
}

gboolean level_properties_changed(void)
{
	if(current_level != NULL)
	{		
		GtkWidget *en_level_name;
		GtkWidget *en_theme_name;
		GtkWidget *en_file_name;
		GtkWidget *sb_time_minutes;
		GtkWidget *sb_time_seconds;
		gchar *new_level_name;
		gchar *new_theme_name; 
		gchar *new_file_name;
		gboolean time_changed = FALSE;
		gboolean file_name_changed = FALSE;
		guint minutes;
		guint seconds;
		
		en_level_name = lookup_widget(get_app(), "level_name");
		en_theme_name = lookup_widget(get_app(), "theme_name_entry");
		en_file_name = lookup_widget(get_app(), "file_name");
		sb_time_minutes = lookup_widget(get_app(), "time_minutes");
		sb_time_seconds = lookup_widget(get_app(), "time_seconds");
		
		/* level name changed? */
		new_level_name = gtk_editable_get_chars(GTK_EDITABLE(en_level_name),0,-1);
		level_name_changed = (g_strcasecmp(new_level_name, 
						   current_level->name)!=0);
		
		/* theme name changed? */
		new_theme_name = gtk_editable_get_chars(GTK_EDITABLE(en_theme_name), 0,-1);
		theme_changed = (g_strcasecmp(new_theme_name, 
					      current_level->theme_name)!=0);
		
		/* file name changed? */
		new_file_name =  gtk_editable_get_chars(GTK_EDITABLE(en_file_name), 0,-1);
		file_name_changed = (g_strcasecmp(new_file_name, 
				      current_level->file_name)!=0);

		/* time changed? */
		minutes = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(sb_time_minutes));
		seconds = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(sb_time_seconds));
		time_changed = (current_level->time != (minutes*60 + seconds));
		
		g_free(new_file_name);
		g_free(new_level_name);
		g_free(new_theme_name);
		
		return (level_name_changed || 
			theme_changed || 
			file_name_changed || 
			time_changed);
	}
	return FALSE;
}

gboolean level_properties_theme_changed(void)
{
	return theme_changed;
}

gboolean level_properties_name_changed(void)
{
	return level_name_changed;
}
