/* Atomixed -- the level-/themeeditor for atomix.
 * Copyright (C) 1999-2000 Jens Finke
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gnome.h>
#include "main.h"
#include "interface.h"
#include "support.h"
#include "level.h"
#include "theme.h"
#include "playfield_editor.h"
#include "level_ctrl.h"
#include "image_win_ctrl.h"
#include "level_properties.h"

GtkWidget *app;
PlayFieldEditor *level_editor;
PlayFieldEditor *goal_editor;
GtkWidget *img_window = NULL;


GtkWidget* get_app()
{
	return app;
}

PlayFieldEditor* get_level_editor()
{
	return level_editor;
}

PlayFieldEditor* get_goal_editor(void)
{
	return goal_editor;
}


Theme* get_theme_by_name(gchar *name)
{
	return NULL;
}

void theme_image_win_hide()
{
	if(img_window)
	{
		gtk_widget_hide(GTK_WIDGET(img_window));
	}
}

void theme_image_win_show()
{
	if(img_window)
	{
		gtk_widget_show(GTK_WIDGET(img_window));
	}
}

void theme_image_win_destroy()
{
	if(img_window)
	{
		gtk_widget_destroy(GTK_WIDGET(img_window));
	}
}


void init(void)
{
	Level *level;
	Theme *theme;
	level = level_ctrl_get_actual_level();
	if(level != NULL)
	{
		theme = theme_load_xml(level->theme_name);	
		
		playfield_editor_set_theme(level_editor, theme);
		playfield_editor_set_theme(goal_editor, theme);
		playfield_editor_set_playfield(level_editor, level->playfield);
		playfield_editor_set_playfield(goal_editor, level->goal);
		level_properties_set_level(level);
		
		image_win_ctrl_set_theme(theme);
	}
}

int
main (int argc, char *argv[])
{
	GtkWidget *menu_item;

	bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
	textdomain (PACKAGE);
	
	gnome_init ("atomixed", VERSION, argc, argv);
	
	app = create_mainframe ();
	
	level_create_hash_table();
	theme_create_hash_table();
	
	level_ctrl_init();
	
	level_editor = playfield_editor_new("level_canvas", TRUE);
	goal_editor = playfield_editor_new("goal_canvas", FALSE);
	playfield_editor_init(level_editor);
	playfield_editor_init(goal_editor);
	
	img_window = create_theme_image_win();	
	image_win_ctrl_init(img_window);

	/* update button state */
	menu_item = GTK_WIDGET(lookup_widget(get_app(), "item_grid"));
	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menu_item), TRUE);

	init();
	
	gtk_widget_show (app);
	
	gtk_main ();
	return 0;
}


